SystemOrganization addCategory: #'GT-Metaceller-Tests'!

TestCase subclass: #GTMetacellerTestCase
	instanceVariableNames: 'testConfigurationClass'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Metaceller-Tests'!

GTMetacellerTestCase subclass: #GTMetacellerConfigurationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Metaceller-Tests'!

!GTMetacellerConfigurationTest methodsFor: 'tests' stamp: 'DiegoLont 3/26/2014 13:53'!
testChildren
	| configuration |
	configuration := GTMetacellerConfiguration on: testConfigurationClass.
	Smalltalk at: #ConfigurationOfGToolkit
		ifAbsent: [ self assert: configuration children isEmpty ]! !

!GTMetacellerConfigurationTest methodsFor: 'tests' stamp: 'DiegoLont 9/18/2013 15:42'!
testMainProject
	| configuration |
	configuration := GTMetacellerConfiguration on: testConfigurationClass.
	self deny: configuration mainProject hasAttributes! !

!GTMetacellerConfigurationTest methodsFor: 'tests' stamp: 'DiegoLont 3/28/2014 10:42'!
testProjects
	| configuration |
	configuration := GTMetacellerConfiguration on: testConfigurationClass.
	self assert: configuration projects size equals: 4! !

!GTMetacellerConfigurationTest methodsFor: 'tests' stamp: 'DiegoLont 9/18/2013 15:50'!
testShortName
	| configuration |
	configuration := GTMetacellerConfiguration on: testConfigurationClass.
	self assert: configuration shortName equals: 'TestForMetaceller'! !

GTMetacellerTestCase subclass: #GTMetacellerItemTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Metaceller-Tests'!

!GTMetacellerItemTest methodsFor: 'tests' stamp: 'DiegoLont 4/2/2014 14:49'!
testItemChangeUsingSpec
	| mainProject item1 item2 |
	mainProject := (GTMetacellerConfiguration on: testConfigurationClass) mainProject.
	item1 := (mainProject version: '1.0-baseline') commonVersion item: 'GT-Metaceller-Streams'.
	item1 saveWithSpecString: 'aSpec
		package: ''GT-Metaceller-Streams'''.
	self assert: item1 requires size equals: 1.
	item1 childVersions do: [ :each |
		self assert: each requires size equals: 1 ].
	mainProject := (GTMetacellerConfiguration on: testConfigurationClass) mainProject.
	item2 := (mainProject version: '1.0-baseline') commonVersion item: 'GT-Metaceller-Streams'.
	self assert: item2 requires size equals: 0.
	item2 childVersions do: [ :each |
		self assert: each requires size equals: 0 ]! !

GTMetacellerTestCase subclass: #GTMetacellerModelTest
	instanceVariableNames: 'model'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Metaceller-Tests'!

!GTMetacellerModelTest methodsFor: 'setUp' stamp: 'DiegoLont 3/14/2014 13:33'!
createOnSetup
	^false! !

!GTMetacellerModelTest methodsFor: 'setUp' stamp: 'DiegoLont 3/14/2014 13:45'!
setUp
	super setUp.
	model := GTMetacellerModel new! !

!GTMetacellerModelTest methodsFor: 'tests' stamp: 'DiegoLont 3/14/2014 13:45'!
testCreateClass
	| currentCount |
	currentCount := model configs size.
	self createTestConfigurationClass.
	self assert: model configs size equals: currentCount +1! !

GTMetacellerTestCase subclass: #GTMetacellerPackageTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Metaceller-Tests'!

!GTMetacellerPackageTest methodsFor: 'tests' stamp: 'DiegoLont 3/28/2014 10:47'!
testPlatformCommon
	| package |
	package := ((GTMetacellerConfiguration on: testConfigurationClass) mainProject version: '1.1') package: 'GT-Metaceller-Model'.
	self assert: package platforms size equals: 2. " we also have one for the platform pHaRo ... somehow "
	self assert: (package platforms contains: [ :each | each hasSymbol:#'common' ])! !

!GTMetacellerPackageTest methodsFor: 'tests' stamp: 'DiegoLont 3/26/2014 13:34'!
testPlatformGemstone
	| package |
	package := ((GTMetacellerConfiguration on: testConfigurationClass) mainProject version: '1.1') package: 'GlamourCore'.
	self assert: package isNil! !

!GTMetacellerPackageTest methodsFor: 'tests' stamp: 'DiegoLont 3/26/2014 13:34'!
testPlatformPharo
	| package |
	package := ((GTMetacellerConfiguration on: testConfigurationClass) mainProject version: '1.1') package: 'GlamourTools'.
	self assert: package platforms size equals: 1.
	self assert: (package platforms includes: (GTPlatformDescription onSymbol: #'pharo'))! !

GTMetacellerTestCase subclass: #GTMetacellerProjectTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Metaceller-Tests'!

!GTMetacellerProjectTest methodsFor: 'tests' stamp: 'DiegoLont 3/26/2014 13:34'!
testCreateVersion
	| mainProject |
	mainProject := (GTMetacellerConfiguration on: testConfigurationClass) mainProject.
	(mainProject createSnapshotVersion: '1.2' baseline: '1.1-baseline').
	self assert: (testConfigurationClass includesSelector: #version12:)! !

!GTMetacellerProjectTest methodsFor: 'tests' stamp: 'DiegoLont 3/26/2014 13:34'!
testGemstone
	| project version |
	project := (GTMetacellerConfiguration on: testConfigurationClass) projectFor: #gemstone.
	version := project version: '1.1-baseline'.
	self assert: version packages size equals: 3.
	self assert: version projects size equals: 1! !

!GTMetacellerProjectTest methodsFor: 'tests' stamp: 'DiegoLont 3/28/2014 10:13'!
testProjects
	| mainProject |
	mainProject := (GTMetacellerConfiguration on: testConfigurationClass) mainProject.
	self assert: mainProject projects size equals: mainProject platformSymbols size! !

!GTMetacellerProjectTest methodsFor: 'tests' stamp: 'DiegoLont 3/28/2014 10:13'!
testSymbols
	| mainProject |
	mainProject := (GTMetacellerConfiguration on: testConfigurationClass) mainProject.
	self assert: mainProject platformSymbols size equals: 4.
	self assert: (mainProject platformSymbols includes: #'common').
	self assert: (mainProject platformSymbols includes: #'gemstone').
	self assert: (mainProject platformSymbols includes: #'pharo').
	self assert: (mainProject platformSymbols includes: #'pHaRo').! !

!GTMetacellerProjectTest methodsFor: 'tests' stamp: 'DiegoLont 3/28/2014 10:12'!
testVersions
	| mainProject |
	mainProject := (GTMetacellerConfiguration on: testConfigurationClass) mainProject.
	self assert: mainProject versions size equals: 4.
	self assert: (mainProject versions contains: [ :each | each versionName  ='1.1-baseline' ]).
	self assert: (mainProject versions contains: [ :each | each versionName ='1.1' ]).
	self assert: (mainProject version: '1.1-baseline') packagesAndProjects size equals: 8
! !

!GTMetacellerTestCase methodsFor: 'setUp' stamp: 'DiegoLont 3/14/2014 13:32'!
createOnSetup
	^true! !

!GTMetacellerTestCase methodsFor: 'setUp' stamp: 'DiegoLont 3/21/2014 15:48'!
createTestConfigurationClass
	testConfigurationClass := Object
		subclass: #ConfigurationOfTestForMetaceller
		instanceVariableNames: 'project'
		classVariableNames: ''
		poolDictionaries: ''
		category: 'GT-ConfigurationOfMetaceller-Tests'.
	testConfigurationClass class
		compile: 'project
	^self new project' classified: 'metacello'.
	testConfigurationClass class
		compile: 'ensureMetacello
	Smalltalk at: #MetacelloProject ifAbsent: [
		Gofer new
				url: ''http://seaside.gemtalksystems.com/ss/metacello/'';
				addPackage: ''ConfigurationOfMetacello'';
				load.
		(Smalltalk at: #ConfigurationOfMetacello) loadLatestVersion ]' classified: 'metacello'.
	testConfigurationClass class
		compile: 'isMetacelloConfig	
	^true'.
	testConfigurationClass 
		compile: 'project
	^ project ifNil: [ | constructor |
		self class ensureMetacello.
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project ]' classified: 'metacello'.
		! !

!GTMetacellerTestCase methodsFor: 'setUp' stamp: 'DiegoLont 4/2/2014 14:51'!
createVersion10
	testConfigurationClass
		compile: 'baseline10: aSpec
	<version: ''1.0-baseline''>
	aSpec for: #common do: [ 
		aSpec blessing: #''baseline''.
		aSpec description: ''Just a testDescription for the released version''.
		aSpec author: ''Diego Lont''.
		aSpec repository: ''http://smalltalkhub.com/mc/Moose/GToolkit/main''.

		aSpec package: ''GT-Metaceller-Model'';
			package: ''GT-Metaceller-Streams'' with: [ 
				aSpec requires: #( ''GT-Metaceller-Model'' ) ];
			package: ''GT-Metaceller-Glamour'' with: [ 
				aSpec requires: #( ''GT-Metaceller-Model'' ) ];
			package: ''GT-Metaceller-Tests'' with: [ 
				aSpec requires: #( ''GT-Metaceller-Model'' ) ].
		aSpec
			group: ''Core'' with: #( ''GT-Metaceller-Model'' );
			group: ''Tests'' with: #( ''GT-Metaceller-Tests'' );
			group: ''Glamour'' with: #( ''GT-Metaceller-Glamour'' );
			group: ''All'' with: #( ''Tests'' ''Glamour'' ) ].
	
	aSpec for: #gemstone do: [ 
		aSpec project: ''GlamourCore'' with: [
				aSpec
					className: ''ConfigurationOfGlamour'';
					version: #development;
					loads: #(''Core'');
					repository: ''http://www.smalltalkhub.com/mc/Moose/Glamour/main'' ].
		aSpec package: ''GT-Metaceller-Glamour'' with: [ 
			aSpec requires: #( ''GlamourCore'' ) ] ].

	aSpec for: #pharo do: [ 
		aSpec project: ''GlamourTools'' with: [
				aSpec
					className: ''ConfigurationOfGToolkit'';
					version: #development;
					loads: #( ''GT-Inspector'' );
					repository: ''http://www.smalltalkhub.com/mc/Moose/Glamour/main'' ].
		aSpec package: ''GT-Metaceller-Glamour'' with: [ 
			aSpec requires: #( ''GlamourTools'' ) ] ]' classified: 'baselines'.
	testConfigurationClass
		compile: 'development: spec
	<symbolicVersion: #development>
	spec for: #common version: ''1.0-baseline''' classified: 'symbolicVersions'.
	testConfigurationClass
		compile: 'stable: spec
	<symbolicVersion: #stable>
	spec for: #common version: ''1.0''' classified: 'symbolicVersions'.
	testConfigurationClass
		compile: 'version10: aSpec
	<version: ''1.0'' imports: #( ''1.0-baseline'')>
	aSpec for: #''common'' do: [ 
		aSpec blessing: #''release''.
		aSpec description: ''This is the released version''.
		aSpec author: ''Diego Lont''.
		
		aSpec package: ''GT-Metaceller-Model'' with: ''GT-Metaceller-Model-DiegoLont.22''.
		aSpec package: ''GT-Metaceller-Glamour'' with: ''GT-Metaceller-Glamour-DiegoLont.15''.
		aSpec package: ''GT-Metaceller-Streams'' with: ''GT-Metaceller-Streams-DiegoLont.2'' ].
	aSpec for: #gemstone do: [ 
		aSpec project: ''GlamourCore'' with: ''2.4'' ]' classified: 'versions'! !

!GTMetacellerTestCase methodsFor: 'setUp' stamp: 'DiegoLont 3/28/2014 10:41'!
createVersion11
	testConfigurationClass
		compile: 'baseline11: aSpec
	<version: ''1.1-baseline''>
	aSpec for: #common do: [ 
		aSpec blessing: #''baseline''.
		aSpec description: ''Just a testDescription for the bleeding edge''.
		aSpec repository: ''http://smalltalkhub.com/mc/Moose/GToolkit/main''.

		aSpec package: ''GT-Metaceller-Model'';
			package: ''GT-Metaceller-Glamour'' with: [ 
				aSpec requires: #( ''GT-Metaceller-Model'' ) ];
			package: ''GT-Metaceller-Tests'' with: [ 
				aSpec requires: #( ''GT-Metaceller-Model'' ) ].
		aSpec
			group: ''Core'' with: #( ''GT-Metaceller-Model'' );
			group: ''Tests'' with: #( ''GT-Metaceller-Tests'' );
			group: ''Glamour'' with: #( ''GT-Metaceller-Glamour'' );
			group: ''All'' with: #( ''Tests'' ''Glamour'' ) ].
	
	aSpec for: #gemstone do: [ 
		aSpec project: ''GlamourCore'' with: [
				aSpec
					className: ''ConfigurationOfGlamour'';
					version: #development;
					loads: #(''Core'');
					repository: ''http://www.smalltalkhub.com/mc/Moose/Glamour/main'' ].
		aSpec package: ''GT-Metaceller-Glamour'' with: [ 
			aSpec requires: #( ''GlamourCore'' ) ] ].

	" Make a typo in the symbol to check handling is case insensitive "
	aSpec for: #pHaRo do: [ 
		aSpec package: ''GT-Metaceller-Typo'' with: [ 
			aSpec requires: ''GT-Metacelller-Glamour'' ] ].

	aSpec for: #pharo do: [ 
		aSpec project: ''GlamourTools'' with: [
				aSpec
					className: ''ConfigurationOfGToolkit'';
					version: #development;
					loads: #( ''GT-Inspector'' );
					repository: ''http://www.smalltalkhub.com/mc/Moose/Glamour/main'' ].
		aSpec package: ''GT-Metaceller-Glamour'' with: [ 
			aSpec requires: #( ''GlamourTools'' ) ] ]' classified: 'baselines'.
	testConfigurationClass
		compile: 'bleedingEdge: spec
	<symbolicVersion: #bleedingEdge>
	spec for: #common version: ''baseline-1.1''' classified: 'symbolicVersions'.
	testConfigurationClass
		compile: 'development: spec
	<symbolicVersion: #development>
	spec for: #common version: ''1.1''' classified: 'symbolicVersions'.
	testConfigurationClass
		compile: 'version11: aSpec
	<version: ''1.1'' imports: #( ''1.1-baseline'')>
	aSpec for: #''common'' do: [ 
		aSpec blessing: #''development''.
		aSpec description: ''Just the development branch, so no version specified for now.''.
		aSpec author: ''Diego Lont'' ]' classified: 'versions'! !

!GTMetacellerTestCase methodsFor: 'setUp' stamp: 'DiegoLont 3/26/2014 13:31'!
setUp
	super setUp.
	self createOnSetup ifTrue: [
		self createTestConfigurationClass.
		self createVersion10.
		self createVersion11 ]! !

!GTMetacellerTestCase methodsFor: 'setUp' stamp: 'DiegoLont 3/14/2014 13:32'!
tearDown
	super tearDown.
	testConfigurationClass ifNotNil: [ testConfigurationClass removeFromSystem ]
	
! !

GTMetacellerTestCase subclass: #GTMetacellerVersionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Metaceller-Tests'!

!GTMetacellerVersionTest methodsFor: 'asserting' stamp: 'DiegoLont 3/27/2014 14:07'!
assertCleanVersion: aMethodString
	self assert: (aMethodString findString: 'file:') equals: 0.
	self assert: (aMethodString findString: 'repository:') equals: 0! !

!GTMetacellerVersionTest methodsFor: 'asserting' stamp: 'DiegoLont 3/24/2014 12:24'!
assertItem: anItem equals: anItem2
	self assert: anItem class equals: anItem2 class.
	self assert: anItem itemName equals: anItem2 itemName! !

!GTMetacellerVersionTest methodsFor: 'asserting' stamp: 'DiegoLont 3/24/2014 14:49'!
assertVersion: aVersion equals: aVersion2
	self assert: aVersion packagesAndProjects size equals: aVersion2 packagesAndProjects size.
	aVersion packagesAndProjects do: [ :each |
		self assertItem: each equals: (aVersion2 itemFor: each itemName) ].
	self assert: aVersion category equals: aVersion2 category.
	self assert: aVersion repositoriesToWrite equals: aVersion2 repositoriesToWrite! !

!GTMetacellerVersionTest methodsFor: 'asserting' stamp: 'DiegoLont 4/1/2014 09:52'!
denyEmptySpecIn: aMethodString
	self assert: (aMethodString findString: 'yourself') equals: 0! !

!GTMetacellerVersionTest methodsFor: 'tests' stamp: 'DiegoLont 3/26/2014 13:38'!
testBaselineCopy
	| mainProject version1 version2 oldSize |
	mainProject := (GTMetacellerConfiguration on: testConfigurationClass) mainProject.
	oldSize := mainProject versions size.
	version1 := mainProject version:'1.1-baseline'.
	version1 saveAs: '1.2-baseline'.
	mainProject := (GTMetacellerConfiguration on: testConfigurationClass) mainProject.
	self assert: mainProject versions size equals: oldSize +1.
	self assert: (mainProject versions contains: [ :each | each versionName ='1.2-baseline' ]).
	version2 := mainProject version: '1.2-baseline'.
	self assertVersion: version1 equals: version2! !

!GTMetacellerVersionTest methodsFor: 'tests' stamp: 'DiegoLont 3/26/2014 13:35'!
testBaselineGemstoneCopy
	| config version gemstoneVersion1 gemstoneVersion2 |
	config := (GTMetacellerConfiguration on: testConfigurationClass).
	version := config mainProject version:'1.1-baseline'.
	gemstoneVersion1 := (config projectFor: #gemstone) version:'1.1-baseline'.
	version saveAs: '1.2-baseline'.
	config := (GTMetacellerConfiguration on: testConfigurationClass).
	gemstoneVersion2 := (config projectFor: #gemstone) version:'1.2-baseline'.
	self assertVersion: gemstoneVersion1 equals: gemstoneVersion2! !

!GTMetacellerVersionTest methodsFor: 'tests' stamp: 'DiegoLont 4/2/2014 14:14'!
testVersionCopy
	| mainProject version1 version2 oldSize |
	mainProject := (GTMetacellerConfiguration on: testConfigurationClass) mainProject.
	oldSize := mainProject versions size.
	version1 := mainProject version: '1.1'.
	version1 saveAs: '1.2'.
	mainProject := (GTMetacellerConfiguration on: testConfigurationClass) mainProject.
	self assert: mainProject versions size equals: oldSize +1.
	self assert: (mainProject versions contains: [ :each | each versionName ='1.2' ]).
	version2 := mainProject version: '1.2'.
	self assertVersion: version2 equals: version1.
	self deny: (version2 methodString includesSubstring: '''repository''').
	self deny: (version2 methodString includesSubstring: '#''pharo''').
	self deny: (version2 methodString includesSubstring: '#''gemstone''').
	self denyEmptySpecIn: version2 methodString
! !

!GTMetacellerVersionTest methodsFor: 'tests' stamp: 'DiegoLont 3/31/2014 09:13'!
testVersionCopyUsingSpec
	| mainProject version1 version2 oldSize |
	mainProject := (GTMetacellerConfiguration on: testConfigurationClass) mainProject.
	oldSize := mainProject versions size.
	version1 := mainProject version: '1.0'.
	version1 commonVersion saveWithSpecString: 'version101: aSpec
	<version: ''1.0.1'' imports:#( ''1.0-baseline'' )>
	aSpec
		description: ''A changed description'';
		yourself'.
	mainProject := (GTMetacellerConfiguration on: testConfigurationClass) mainProject.
	self assert: mainProject versions size equals: oldSize +1.
	self assert: (mainProject versions contains: [ :each | each versionName ='1.0.1' ]).
	version2 := mainProject version: '1.0.1'.
	self assertVersion: version2 equals: version1.
	self deny: (version2 methodString includesSubstring: '#''pharo''').
	self assert: (version2 methodString includesSubstring: '#''gemstone''').
	self denyEmptySpecIn: version2 methodString.
	self assertCleanVersion: version2 methodString.
	self assert: version2 description equals: 'A changed description'.
	self assert: version2 blessing equals: #'development'.
	self assert: version2 author equals: Author fullName.
	self assert: version2 timestamp equals: DateAndTime now asDate yyyymmdd! !

!GTMetacellerVersionTest methodsFor: 'tests' stamp: 'DiegoLont 3/26/2014 14:31'!
testVersionCopyWithVersions
	| mainProject version1 version2 oldSize |
	mainProject := (GTMetacellerConfiguration on: testConfigurationClass) mainProject.
	oldSize := mainProject versions size.
	version1 := mainProject version: '1.0'.
	version1 saveAs: '1.0.1'.
	mainProject := (GTMetacellerConfiguration on: testConfigurationClass) mainProject.
	self assert: mainProject versions size equals: oldSize +1.
	self assert: (mainProject versions contains: [ :each | each versionName ='1.0.1' ]).
	version2 := mainProject version: '1.0.1'.
	self assertVersion: version2 equals: version1.
	self deny: (version2 methodString includesSubstring: '#''pharo''').
	self assert: (version2 methodString includesSubstring: '#''gemstone''').
	self denyEmptySpecIn: version2 methodString
! !

TestCase subclass: #GTMetacellerVersionNameTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-Metaceller-Tests'!

!GTMetacellerVersionNameTest methodsFor: 'tests' stamp: 'DiegoLont 3/30/2014 10:37'!
testAlpha
	self assert: ('3.2.alfa' asMetacellerVersion) < ('3.2.beta' asMetacellerVersion).
	self assert: ('alfa.1' asMetacellerVersion) < ('alfa.2' asMetacellerVersion)! !

!GTMetacellerVersionNameTest methodsFor: 'tests' stamp: 'DiegoLont 3/30/2014 10:36'!
testMissing
	self assert: ('3.2.1' asMetacellerVersion) > ('3.2' asMetacellerVersion).
	self deny: ('3.2.1' asMetacellerVersion) < ('3.2' asMetacellerVersion)! !

!GTMetacellerVersionNameTest methodsFor: 'tests' stamp: 'DiegoLont 3/30/2014 10:35'!
testSimple
	self assert: ('3.2.1' asMetacellerVersion) > ('2.2.1' asMetacellerVersion).
	self assert: ('3.2.1' asMetacellerVersion) > ('3.1.1' asMetacellerVersion).
	self assert: ('3.2.1' asMetacellerVersion) > ('3.2.0' asMetacellerVersion).! !
